#  Drakkar-Software OctoBot-CLI
#  Copyright (c) Drakkar-Software, All rights reserved.
#
#  This library is free software; you can redistribute it and/or
#  modify it under the terms of the GNU Lesser General Public
#  License as published by the Free Software Foundation; either
#  version 3.0 of the License, or (at your option) any later version.
#
#  This library is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
#  Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public
#  License along with this library.

PROJECT_NAME = "OctoBot-CLI"
VERSION = "1.0.7"  # major.minor.revision

OCTOBOT_PACKAGE = "OctoBot >= 0.4.0b"

DEFAULT_VENV_PATH = "venv"

OCTOBOT_IMAGE = "drakkarsoftware/octobot"
OCTOBOT_PI_IMAGE = "drakkarsoftware/octobot-pi"
OCTOBOT_CONTAINER_NAME = "octobot"
OCTOBOT_LATEST_TAG = "latest"
OCTOBOT_STABLE_TAG = "0.4.0-stable"
OCTOBOT_STABLE_NIGHTLY = "0.4.0"

CONTAINER_DEFAULT_PUBLISH_PORT = 5001
